summaryrefslogtreecommitdiff
path: root/lib/MC/MCDwarf.cpp
diff options
context:
space:
mode:
authorKevin Enderby <enderby@apple.com>2012-01-10 21:12:34 +0000
committerKevin Enderby <enderby@apple.com>2012-01-10 21:12:34 +0000
commit11c2defa9157bd589cb322218c718c4492ed5746 (patch)
treeee197c9604572babe00909dc0e0721a27731bec6 /lib/MC/MCDwarf.cpp
parentf1f16c832f92829f47573620c20d8420c47bde6c (diff)
downloadllvm-11c2defa9157bd589cb322218c718c4492ed5746.tar.gz
llvm-11c2defa9157bd589cb322218c718c4492ed5746.tar.bz2
llvm-11c2defa9157bd589cb322218c718c4492ed5746.tar.xz
This is the matching change for the data structure name changes for the
functional change in r147860 to use DW_TAG_label's instead TAG_subprogram's. This only changes names and updates comments. No functional change. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@147877 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/MC/MCDwarf.cpp')
-rw-r--r--lib/MC/MCDwarf.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/lib/MC/MCDwarf.cpp b/lib/MC/MCDwarf.cpp
index 83fa0690e9..d8604d4b8e 100644
--- a/lib/MC/MCDwarf.cpp
+++ b/lib/MC/MCDwarf.cpp
@@ -631,13 +631,13 @@ static void EmitGenDwarfInfo(MCStreamer *MCOS) {
// Third part: the list of label DIEs.
- // Loop on saved info for dwarf subprograms and create the DIEs for them.
- const std::vector<const MCGenDwarfSubprogramEntry *> &Entries =
- MCOS->getContext().getMCGenDwarfSubprogramEntries();
- for (std::vector<const MCGenDwarfSubprogramEntry *>::const_iterator it =
+ // Loop on saved info for dwarf labels and create the DIEs for them.
+ const std::vector<const MCGenDwarfLabelEntry *> &Entries =
+ MCOS->getContext().getMCGenDwarfLabelEntries();
+ for (std::vector<const MCGenDwarfLabelEntry *>::const_iterator it =
Entries.begin(), ie = Entries.end(); it != ie;
++it) {
- const MCGenDwarfSubprogramEntry *Entry = *it;
+ const MCGenDwarfLabelEntry *Entry = *it;
// The DW_TAG_label DIE abbrev (2).
MCOS->EmitULEB128IntValue(2);
@@ -666,12 +666,12 @@ static void EmitGenDwarfInfo(MCStreamer *MCOS) {
// Add the NULL DIE terminating the DW_TAG_unspecified_parameters DIE's.
MCOS->EmitIntValue(0, 1);
}
- // Deallocate the MCGenDwarfSubprogramEntry classes that saved away the info
- // for the dwarf subprograms.
- for (std::vector<const MCGenDwarfSubprogramEntry *>::const_iterator it =
+ // Deallocate the MCGenDwarfLabelEntry classes that saved away the info
+ // for the dwarf labels.
+ for (std::vector<const MCGenDwarfLabelEntry *>::const_iterator it =
Entries.begin(), ie = Entries.end(); it != ie;
++it) {
- const MCGenDwarfSubprogramEntry *Entry = *it;
+ const MCGenDwarfLabelEntry *Entry = *it;
delete Entry;
}
@@ -711,11 +711,11 @@ void MCGenDwarfInfo::Emit(MCStreamer *MCOS) {
// When generating dwarf for assembly source files this is called when symbol
// for a label is created. If this symbol is not a temporary and is in the
// section that dwarf is being generated for, save the needed info to create
-// a dwarf subprogram.
+// a dwarf label.
//
-void MCGenDwarfSubprogramEntry::Make(MCSymbol *Symbol, MCStreamer *MCOS,
+void MCGenDwarfLabelEntry::Make(MCSymbol *Symbol, MCStreamer *MCOS,
SourceMgr &SrcMgr, SMLoc &Loc) {
- // We won't create dwarf subprogram's for temporary symbols or symbols not in
+ // We won't create dwarf label's for temporary symbols or symbols not in
// the default text.
if (Symbol->isTemporary())
return;
@@ -723,17 +723,17 @@ void MCGenDwarfSubprogramEntry::Make(MCSymbol *Symbol, MCStreamer *MCOS,
if (context.getGenDwarfSection() != MCOS->getCurrentSection())
return;
- // The dwarf subprogram's name does not have the symbol name's leading
+ // The dwarf label's name does not have the symbol name's leading
// underbar if any.
StringRef Name = Symbol->getName();
if (Name.startswith("_"))
Name = Name.substr(1, Name.size()-1);
- // Get the dwarf file number to be used for the dwarf subprogram.
+ // Get the dwarf file number to be used for the dwarf label.
unsigned FileNumber = context.getGenDwarfFileNumber();
// Finding the line number is the expensive part which is why we just don't
- // pass it in as for some symbols we won't create a dwarf subprogram.
+ // pass it in as for some symbols we won't create a dwarf label.
int CurBuffer = SrcMgr.FindBufferContainingLoc(Loc);
unsigned LineNumber = SrcMgr.FindLineNumber(Loc, CurBuffer);
@@ -745,9 +745,9 @@ void MCGenDwarfSubprogramEntry::Make(MCSymbol *Symbol, MCStreamer *MCOS,
MCOS->EmitLabel(Label);
// Create and entry for the info and add it to the other entries.
- MCGenDwarfSubprogramEntry *Entry =
- new MCGenDwarfSubprogramEntry(Name, FileNumber, LineNumber, Label);
- MCOS->getContext().addMCGenDwarfSubprogramEntry(Entry);
+ MCGenDwarfLabelEntry *Entry =
+ new MCGenDwarfLabelEntry(Name, FileNumber, LineNumber, Label);
+ MCOS->getContext().addMCGenDwarfLabelEntry(Entry);
}
static int getDataAlignmentFactor(MCStreamer &streamer) {